@@ -7,6 +7,11 @@ import string
 from random import choice
 import random as rd
 import base64 as b64
+import re
+import os
+import signal
+import requests
+import json
 
 KEYS_RSA = rsa.newkeys(512)
 
@@ -16,42 +21,93 @@ class LIB:
         pass
 
     @staticmethod
-    def base64_encrypt(word: str = ''):
-        encoded = (b64.b64encode(word.encode("ascii")))
-        encoded_ascii = encoded.decode("ascii")
+    def ping(hostname):
+        # hostname = "google.com"  # example
+        response = os.system("ping -n 1 " + hostname + " >> trash_ping.log")
+        # and then check the response...
+        if response == 0:
+            result = f"""{hostname} Sucesso!"""
+        else:
+            result = f"""{hostname} Não encontrado!"""
+        return result
+
+    @staticmethod
+    def post_message_to_slack(token, channel, text, icon_emoji, username, blocks=None, url="https://slack.com/api/chat.postMessage" ):
+        return requests.post(url,
+                             {'token': token,
+                              'channel': channel,
+                              'text': text,
+                              'icon_emoji': icon_emoji,
+                              'username': username,
+                              'blocks': json.dumps(blocks) if blocks else None
+                              }
+                             ).json()
+
+    @staticmethod
+    def getPID():
+        return os.getpid()
+
+    @staticmethod
+    def killPID(pid):
+        result = True
+        try:
+            os.kill(pid, signal.SIGKILL)
+        except Exception as error:
+            result = False
+        finally:
+            return result
+
+    @staticmethod
+    def colunas_cursor(cursor) -> list:
+        header = [head[0] for head in cursor.description]
+        return header
+
+    @staticmethod
+    def base64_encrypt(word: str, encode_pattern: str = "utf-8"):
+        encoded = (b64.b64encode(word.encode(encode_pattern)))
+        encoded_ascii = encoded.decode(encode_pattern)
         return encoded_ascii
 
     @staticmethod
-    def base64_decrypt(word: str):
-        decoded_ascii = None
+    def base64_decrypt(word: str, encode_pattern: str = "utf-8"):
         try:
-            decoded = b64.b64decode(word.encode('ascii'))
-            decoded_ascii = decoded.decode('ascii')
+            word = word.encode(encode_pattern)
+            decoded = b64.b64decode(word).decode(encode_pattern)
+            #decoded_ascii = decoded.decode()
         except Exception as error:
-            decoded_ascii = error
+            decoded = error
         finally:
-            return decoded_ascii
-
+            return decodede
 
     @staticmethod
-    def token_get(word: str = None) -> str:
-        key = Fernet.generate_key()
-        #f = Fernet(key)
-        #token = f.encrypt(word.encode())
-        return key
+    def findchar(string: str, pattern: str, ocorrencia: int = None, inicio: int = 0, fim: int = 0, trim: bool = True):
+        try:
+            if trim:
+                string = string.strip()
+            if fim == 0:
+                fim = len(string)
+            if fim > inicio and (fim-inicio) > len(pattern):
+                string = string[inicio:fim]
+            if ocorrencia is not None:
+                locate = re.findall(pattern, string)
+                if ocorrencia is not None:
+                    if ocorrencia > len(locate):
+                        locate = locate[len(locate)-1]
 
-    @staticmethod
-    def findchar(string: str, substring: str, ocorrencia: int, inicio: int = 0, fim: int = None):
-        if fim is None:
-            fim = len(string)
-        if substring is None:
-            return None
-        if string is None:
-            return None
-        if ocorrencia is None:
-            ocorrencia = 1
-        while True:
-            pass
+
+        except Exception as error:
+            locate = error
+        finally:
+            return locate
+
+
+        # ocorrencia_localizada = []
+        # while (True):
+        #     str = string[string.find(substring):string.find(substring) + len(substring)]
+        #     ocorrencia_localizada.append(str)
+        #     if str == '':
+        #         break
+        # print(ocorrencia_localizada)
 
     @staticmethod
     def build_key(size: int = 24,
@@ -260,106 +316,27 @@ class LIB:
             return result
 
     @staticmethod
-    def CRYPTOGRAPHY(word, action: str = "D", token: str = None):
-        # D=Decrypt, E=Encrypt
-        result = None
+    def token_get() -> str:
+        key = Fernet.generate_key()
+        cipher_suite = Fernet(key)
+        # return key.decode("ascii")
+        return cipher_suite
+
+    @staticmethod
+    def CRYPTOGRAPHY(word: str, token: str = None, action: str = "E"):
+        msg, result = None, None
         try:
-            if word is None:
-                raise Exception(f"""Parametro "word" é obrigatorio!""")
-            if token is None:
-                raise Exception(f"""Parametro "token" é obrigatório""")
-            if isinstance(word, str):
-                word = word.encode()
-            CIPHER = Fernet(token)
             if action == "E":
-                if type(word == "str"):
-                    result = CIPHER.encrypt(word)
+                if isinstance(word, str):
+                    word = word.encode()
+                result = token.encrypt(word).decode()
             else:
-                result = CIPHER.decrypt(word)
+                if isinstance(word, str):
+                    word = word.encode()
+                result = token.decrypt(word).decode()
         except Exception as error:
-            result = error.encode()
-        finally:
-            return result.decode()
-
-    # @staticmethod
-    # def get_parametros_geral(conexao) -> pd.DataFrame:
-    #     df = None
-    #     now = dt.datetime.now()
-    #     status = 'A' # Ativo
-    #     try:
-    #         sql = f"""
-    #                SELECT *
-    #                  FROM Parametros
-    #                 where flg_status = 'A'
-    #                   and to_date({now.astype(str)}, "%Y-%m-%d %H:%MM:%S") between dat_ini_vigencia and dat_fim_vigencia
-    #                   and flg_status = '{status}'
-    #                 order by handle_parent, handle, num_ordem
-    #                """
-    #         df = pd.read_sql(con=conexao, sql=sql)
-    #     except Exception as error:
-    #         df = error
-    #     finally:
-    #         return df
-
-    @staticmethod
-    def get_parametro_valor(df, value) -> str:
-        result = None
-        try:
-            index = df.loc[df["nom_variavel"] == value].index[0]
-            result = df.loc[index, "val_parametro"]
-        except Exception as error:
-            result = None
-        finally:
-            return result
-
-    @staticmethod
-    def get_parametro_valor_index(df, value) -> int:
-        result = None
-        try:
-            result = df.loc[df["nom_variavel"] == value].index[0]
-        except Exception as error:
-            result = None
-        finally:
-            return result
-
-    # @staticmethod
-    # def get_parametros_grupo(df, value) -> pd.DataFrame:
-    #     result = None
-    #     try:
-    #         result = df.loc[df["grupo_parametro"] == value]
-    #     except Exception as error:
-    #         result = error
-    #     finally:
-    #         return result
-
-    # @staticmethod
-    # def get_parametros_familia(df, value) -> pd.DataFrame:
-    #     result = None
-    #     try:
-    #         result = df.loc[df["familia"] == value]
-    #     except Exception as error:
-    #         result = error
-    #     finally:
-    #         return result
-        
-    @staticmethod
-    def parametro_set(conexao, nom_parametro, val_parametro):
-        result = None
-        try:
-            sql = f"""
-                    Update Parametros
-                       set val_parametro = '{val_parametro}'
-                     where nom_variavel = = '{nom_parametro}'   
-                  """
-            cursor = conexao.cursor()
-            cursor.execute(sql)
-            conexao.commit()
-            conexao.close()
-        except Exception as error:
-            msg = f"""Falha ao tentar gravar o parametro [{nom_parametro}, com o valor [{val_parametro}], nesta conexão [{conexao}]. Erro: {error}"""
+            msg = error.args[0]
             result = msg
-            if conexao.isopen():
-                conexao.close()
         finally:
             return result
 
